@@ -1,8 +1,8 @@
 !== dc_date.f90 - դӻ˴ؤ³󶡤⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_date.f90,v 1.19 2006/12/31 19:26:55 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070116 $
+! Version::   $Id: dc_date.f90,v 1.20 2007/03/21 06:59:06 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070417 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 
@@ -876,14 +876,23 @@ contains
     !
     implicit none
     type(DC_DATETIME), intent(in):: time1, time2
+    integer:: year1, year2
     real(DP):: time1_sec, time2_sec
   continue
-    time1_sec = EvalSec(time1) + EvalSec(ZoneToDiff(time1 % zone))
-    time2_sec = EvalSec(time2) + EvalSec(ZoneToDiff(time2 % zone))
-    if (time1_sec > time2_sec) then
+    call Eval(time1, year=year1)
+    call Eval(time2, year=year2)
+    if (year1 > year2) then
       result = .true.
-    else
+    elseif (year1 < year2) then
       result = .false.
+    else
+      time1_sec = EvalSec(time1) + EvalSec(ZoneToDiff(time1 % zone))
+      time2_sec = EvalSec(time2) + EvalSec(ZoneToDiff(time2 % zone))
+      if (time1_sec > time2_sec) then
+        result = .true.
+      else
+        result = .false.
+      end if
     end if
   end function dcdate_gt_tt
 
@@ -938,11 +947,14 @@ contains
     !
     implicit none
     type(DC_DATETIME), intent(in):: time1, time2
+    integer:: year1, year2
     real(DP):: time1_sec, time2_sec
   continue
+    call Eval(time1, year=year1)
+    call Eval(time2, year=year2)
     time1_sec = EvalSec(time1) + EvalSec(ZoneToDiff(time1 % zone))
     time2_sec = EvalSec(time2) + EvalSec(ZoneToDiff(time2 % zone))
-    if (time1_sec == time2_sec) then
+    if (year1 == year2 .and. time1_sec == time2_sec) then
       result = .true.
     else
       result = .false.
