@@ -1,8 +1,8 @@
 !== dc_units.f90 - ñ̷Ͻѥ⥸塼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_units.f90,v 1.4 2006/12/30 08:21:55 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070116 $
+! Version::   $Id: dc_units.f90,v 1.5 2007/03/21 06:58:01 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070417 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -159,7 +159,7 @@ contains
       nullify(result%name, result%power)   
       return
     endif
-    if (all(abs(x%power(1:result%nelems)) < tiny(0.0d0))) then
+    if (all(abs(x%power(1:result%nelems)) < tiny(0.0_DP))) then
       allocate(result%name(result%nelems), result%power(result%nelems))
       result%name = u1%name
       result%power = u1%power
@@ -182,7 +182,7 @@ contains
     debug = x
     if (x%nelems == 0) then
       result = .true.
-    else if (all(abs(x%power(1:x%nelems)) < tiny(0.0d0))) then
+    else if (all(abs(x%power(1:x%nelems)) < tiny(0.0_DP))) then
       result = .true.
     else
       result = .false.
@@ -217,7 +217,7 @@ contains
     integer:: i, ip, npower
     character(TOKEN):: buffer
     character:: mul = '.'
-    real(DP), parameter:: allowed = epsilon(1.0d0) * 16.0
+    real(DP), parameter:: allowed = epsilon(1.0_DP) * 16.0
 
     if (u%nelems < 0) then
       string = 'error from ' // u%offset
