@@ -1,8 +1,8 @@
 !== dc_date_types#DC_DATETIME, dc_date_types#DC_DIFFTIME ѿäؤѴ
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dcdatetimeeval.f90,v 1.7 2006/12/26 18:41:48 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070305 $
+! Version::   $Id: dcdatetimeeval.f90,v 1.8 2007/03/21 06:59:06 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070417 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -294,6 +294,10 @@ function DCDateTimeEvalSec(time) result(result)
   ! dc_date_types#DC_DATETIME ѿä˴
   ! ټ¿ѿ֤ޤ.
   !
+  ! ǯǤ̵뤵ޤ. ʤ, 1999-01-01 Ǽ줿 time 
+  ! 2007-01-01 Ǽ줿 time Ʊ֤ͤޤ.
+  ! (Ϥ⤷˾ޤ̵ư⤷ޤ).
+  !
   use dc_types, only: DP
   use dc_date, only: Eval
   use dc_date_types, only: DC_DATETIME
@@ -334,7 +338,7 @@ function DCDateTimeEvalByUnit(time, unit) result(result)
   !  dc_date_types#UNIT_DAY,  dc_date_types#UNIT_HOUR,
   ! ʬ dc_date_types#UNIT_MIN,  dc_date_types#UNIT_SEC 
   ! Ϳ뤳ȤǽǤ. ˳ʤʸ *unit*
-  ! Ϳ 0.0d0 ֤ޤ.
+  ! Ϳ 0.0 ֤ޤ.
   !
   use dc_types, only: DP, TOKEN
   use dc_date, only: EvalSec, EvalMin, EvalHour, EvalDay, dcdate_parse_unit
@@ -356,7 +360,7 @@ continue
   elseif (trim(unitl) == trim(UNIT_DAY(1))) then
     result = EvalDay(time)
   else
-    result = 0.0d0
+    result = 0.0_DP
   end if
 end function DCDateTimeEvalByUnit
 
@@ -368,7 +372,7 @@ function DCDiffTimeEvalByUnit(diff, unit) result(result)
   !  dc_date_types#UNIT_DAY,  dc_date_types#UNIT_HOUR,
   ! ʬ dc_date_types#UNIT_MIN,  dc_date_types#UNIT_SEC 
   ! Ϳ뤳ȤǽǤ. ˳ʤʸ *unit*
-  ! Ϳ 0.0d0 ֤ޤ.
+  ! Ϳ 0.0 ֤ޤ.
   !
   use dc_types, only: DP, TOKEN
   use dc_date, only: EvalSec, EvalMin, EvalHour, EvalDay, dcdate_parse_unit
@@ -390,7 +394,7 @@ continue
   elseif (trim(unitl) == trim(UNIT_DAY(1))) then
     result = EvalDay(diff)
   else
-    result = 0.0d0
+    result = 0.0_DP
   end if
 end function DCDiffTimeEvalByUnit
 
