@@ -1,8 +1,8 @@
 !== dcunits_com.f90 - ñ̷ϽѤβ̥⥸塼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dcunits_com.f90,v 1.3 2005/12/26 15:10:12 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070305 $
+! Version::   $Id: dcunits_com.f90,v 1.4 2007/03/21 06:58:01 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070417 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -59,7 +59,7 @@ contains
     character(*), intent(out):: cvalue
     integer:: iend, istr, ilen, ios
     ivalue = 0
-    dvalue = 0.0d0
+    dvalue = 0.0_DP
     cvalue = ""
     iend = len_trim(thisline)
     do
