@@ -3,8 +3,8 @@
 #== Makefile.win generator
 #
 #Authors::   Yasuhiro MORIKAWA
-#Version::   $Id: gen-Makefile.win.rb,v 1.3 2007/03/05 15:22:54 morikawa Exp $
-#Tag Name::  $Name: gt4f90io-20070305 $
+#Version::   $Id: gen-Makefile.win.rb,v 1.5 2007/04/17 15:29:20 morikawa Exp $
+#Tag Name::  $Name: gt4f90io-20070417 $
 #Copyright:: Copyright (C) GFD Dennou Club, 2007-. All rights reserved.
 #License::   See COPYRIGHT[link:../../COPYRIGHT]
 #
@@ -59,7 +59,7 @@ if OPTS[:help] || !OPTS[:input] || !OPTS[:output]
 end
 
 win32_gmakeobj = GNUMakefileParser.new('')
-win32_gmakeobj.add('FC = df')
+win32_gmakeobj.add('FC = ifort /MD')
 win32_gmakeobj.add('LIBPROG = lib')
 win32_gmakeobj.add('RM = del')
 win32_gmakeobj.add('SYSDEPABORT=abort')
@@ -91,6 +91,10 @@ gmakeobj.list.collect!{|l|
         p.sub(/\.o$/, '.obj')
       }
     end
+    l.target.gsub!(/^netcdf\_f77\.obj$/, 'netcdf_f77_win.obj')
+    l.prerequisites.collect!{|p|
+      p.sub(/^netcdf\_f77\.obj$/, 'netcdf_f77_win.obj')
+    }
   elsif l.class == GNUMakefileParser::MkVariable
     next false if l.var =~ /^(RB2F90)$/
     if l.var == 'TARGET'
@@ -99,6 +103,9 @@ gmakeobj.list.collect!{|l|
     if l.var =~ /^OBJS/
       l.value.gsub!(/\.o /, '.obj ')
       l.value.gsub!(/\.o$/, '.obj')
+      l.value.gsub!(/^netcdf\_f77\.obj /, 'netcdf_f77_win.obj ')
+      l.value.gsub!(/ netcdf\_f77\.obj /, ' netcdf_f77_win.obj ')
+      l.value.gsub!(/ netcdf\_f77\.obj$/, ' netcdf_f77_win.obj')
     end
   elsif l.class == GNUMakefileParser::MkOther
     if l.line =~ /^(ifeq|ifneq|ifdef|ifndef|else|endif)\s+/
@@ -118,13 +125,18 @@ win32_gmakeobj.add('.f90.obj:
 win32_gmakeobj.add('.f90.mod:
 	$(FC) -c $*.f90
 ')
+win32_gmakeobj.add('install:
+	copy *.mod c:\uty\gt4f90io\lib\module
+	copy *.lib c:\uty\gt4f90io\lib
+')
+
 
 header_msg = <<-EOH
 #= Makefile for build of gt4f90io library in Windows
 #
 # Authors::   Naohito OTOBE (otobe), Yasuhiro MORIKAWA (morikawa)
-# Version::   $Id: gen-Makefile.win.rb,v 1.3 2007/03/05 15:22:54 morikawa Exp $
-# Tag Name::  $Name: gt4f90io-20070305 $
+# Version::   $Id: gen-Makefile.win.rb,v 1.5 2007/04/17 15:29:20 morikawa Exp $
+# Tag Name::  $Name: gt4f90io-20070417 $
 # Copyright:: Copyright (C) GFD Dennou Club, 2007-. All rights reserved.
 # License::   See COPYRIGHT[link:../../COPYRIGHT]
 #
