@@ -1,8 +1,8 @@
 !== Sample program for gt4_history/gt4f90io.
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: histinquire.f90,v 1.4 2006/07/17 15:00:06 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070305 $
+! Version::   $Id: histinquire.f90,v 1.5 2007/04/16 05:58:58 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070417 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../COPYRIGHT]
 !
@@ -16,7 +16,7 @@ program histinquire
     &                    HistoryClose
   use dc_string,only: StoA, Printf, JoinChar, toChar
   use dc_message, only: MessageNotify
-  use dc_test, only: Compare
+  use dc_test, only: AssertEqual
   implicit none
   integer:: length
   character(STRING) :: xtype, units, longname, name
@@ -52,34 +52,34 @@ continue
   call Inquire(gthist, axes=axes)
 
   call Inquire(axes(1), name, length, longname, units, xtype)
-  call Compare('HistoryAxisInquire Test 1 (name)', &
+  call AssertEqual('HistoryAxisInquire Test 1 (name)', &
     & answer='x', check=name)
-  call Compare('HistoryAxisInquire Test 1 (length)', &
+  call AssertEqual('HistoryAxisInquire Test 1 (length)', &
     & answer=3, check=length)
-  call Compare('HistoryAxisInquire Test 1 (longname)', &
+  call AssertEqual('HistoryAxisInquire Test 1 (longname)', &
     & answer='eastward length', check=longname)
-  call Compare('HistoryAxisInquire Test 1 (units)', &
+  call AssertEqual('HistoryAxisInquire Test 1 (units)', &
     & answer='m', check=units)
-  call Compare('HistoryAxisInquire Test 1 (xtype)', &
+  call AssertEqual('HistoryAxisInquire Test 1 (xtype)', &
     & answer='double', check=xtype)
 
   call Inquire(axes(2), name, length, longname, units, xtype)
-  call Compare('HistoryAxisInquire Test 2 (name)', &
+  call AssertEqual('HistoryAxisInquire Test 2 (name)', &
     & answer='time', check=name)
-  call Compare('HistoryAxisInquire Test 2 (length)', &
+  call AssertEqual('HistoryAxisInquire Test 2 (length)', &
     & answer=0, check=length)
-  call Compare('HistoryAxisInquire Test 2 (longname)', &
+  call AssertEqual('HistoryAxisInquire Test 2 (longname)', &
     & answer='time', check=longname)
-  call Compare('HistoryAxisInquire Test 2 (units)', &
+  call AssertEqual('HistoryAxisInquire Test 2 (units)', &
     & answer='sec.', check=units)
-  call Compare('HistoryAxisInquire Test 2 (xtype)', &
+  call AssertEqual('HistoryAxisInquire Test 2 (xtype)', &
     & answer='float', check=xtype)
 
   !
   ! HistoryVarinfoInquire Test
   !
   call Inquire(gthist, err=err, varinfo=varinfo)
-  call Compare('HistoryVarinfoInquire Test 1', answer=.true., check=err)
+  call AssertEqual('HistoryVarinfoInquire Test 1', answer=.true., check=err)
   if (associated(varinfo)) deallocate(varinfo)
 
   call HistoryAddVariable('u', dims=StoA('x', 'time'), &
@@ -88,30 +88,30 @@ continue
     & longname='any average', units='m/s', history=gthist)
 
   call Inquire(gthist, err=err, varinfo=varinfo)
-  call Compare('HistoryVarinfoInquire Test 2', answer=.false., check=err)
+  call AssertEqual('HistoryVarinfoInquire Test 2', answer=.false., check=err)
 
   call Inquire(varinfo(1), name, dims, longname, units, xtype)
-  call Compare('HistoryVarinfoInquire Test 3 (name)', &
+  call AssertEqual('HistoryVarinfoInquire Test 3 (name)', &
     & answer='u', check=name)
-  call Compare('HistoryVarinfoInquire Test 3 (dims)', &
+  call AssertEqual('HistoryVarinfoInquire Test 3 (dims)', &
     & answer=StoA('x', 'time'), check=dims)
-  call Compare('HistoryVarinfoInquire Test 3 (longname)', &
+  call AssertEqual('HistoryVarinfoInquire Test 3 (longname)', &
     & answer='any quantity', check=longname)
-  call Compare('HistoryVarinfoInquire Test 3 (units)', &
+  call AssertEqual('HistoryVarinfoInquire Test 3 (units)', &
     & answer='m/s', check=units)
-  call Compare('HistoryVarinfoInquire Test 3 (xtype)', &
+  call AssertEqual('HistoryVarinfoInquire Test 3 (xtype)', &
     & answer='float', check=xtype)
 
   call Inquire(varinfo(2), name, dims, longname, units, xtype)
-  call Compare('HistoryVarinfoInquire Test 4 (name)', &
+  call AssertEqual('HistoryVarinfoInquire Test 4 (name)', &
     & answer='u_ave', check=name)
-  call Compare('HistoryVarinfoInquire Test 4 (dims)', &
+  call AssertEqual('HistoryVarinfoInquire Test 4 (dims)', &
     & answer=StoA('time'), check=dims)
-  call Compare('HistoryVarinfoInquire Test 4 (longname)', &
+  call AssertEqual('HistoryVarinfoInquire Test 4 (longname)', &
     & answer='any average', check=longname)
-  call Compare('HistoryVarinfoInquire Test 4 (units)', &
+  call AssertEqual('HistoryVarinfoInquire Test 4 (units)', &
     & answer='m/s', check=units)
-  call Compare('HistoryVarinfoInquire Test 4 (xtype)', &
+  call AssertEqual('HistoryVarinfoInquire Test 4 (xtype)', &
     & answer='float', check=xtype)
 
   call HistoryClose(gthist)
